==> 0.3.2%2B24.tar.gz: lib/etc/utility.dart <==
part of viltage;

class Utility {
	static render(List<List<Entity>> entities, List<List<CharNode>> charArray) {
		for(int i = 0; i < entities.length; i++) {
			for(int j = 0; j < entities[i].length; j++) {
				entities[i][j].render(charArray);
			}
		}
	}
	  
	static draw(CanvasRenderingContext2D ctx, int offX, int offY, VilTAGE viltage) {
	  List<List<CharNode>> charArray = viltage.charArray;
	  for(int i = 0; i < charArray.length; i++) {
			for(int j = 0; j < charArray[0].length; j++) {
			  ctx.fillStyle = getImage(charArray[i][j], viltage);
			  ctx.fillRect(j*offX, i*offX, offX, offY);
//			  ctx.drawImage(getImage(charArray[i][j], viltage), j*offX, i*offY);
  		}
	  }
	}
	
	static bool printCaching = false;
	
	static CanvasPattern getImage(CharNode cn, VilTAGE viltage) {
	  CanvasPattern image;
      
	  for(int i = 0; i < cachedNodes.keys.length; i++) {
	    if(cachedNodes.keys.elementAt(i).sameValueAs(cn)) {
	      image = cachedNodes[cachedNodes.keys.elementAt(i)];
	      break;
	    }
	  }
	  
	  if(image == null) {
	    image = createImage(cn, viltage);
	    if(printCaching) print('Cached "${cn.char}" background color: "${cn.backgroundColor==null?viltage.backgroundColor:cn.backgroundColor}" color: "${cn.color}" font: "${cn.fontName==null?viltage.fontName:cn.fontName}" bold: "${cn.bold==null?viltage.bold:cn.bold}" italic: "${cn.italic==null?viltage.italic:cn.italic}"');
	  }
	  
	  return image;
	}
	
	static CanvasPattern createImage(CharNode cn, VilTAGE viltage) {
	  CanvasElement ce = new CanvasElement(width: viltage.offX, height: viltage.offY);
	  if(cn.backgroundColor == null) ce.context2D.fillStyle = viltage.backgroundColor;
	  else ce.context2D.fillStyle = cn.backgroundColor;
	  ce.context2D.fillRect(0, 0, ce.width, ce.height);
	  if(cn.char != null && ce.text != " " && cn.char.length <= 1) {
		  ce.context2D.fillStyle = cn.color;

      String italic = viltage.italic?"italic":"";
      if(cn.italic != null) italic = cn.italic?"italic":"";
      String bold = viltage.bold?"bold":"";
      if(cn.bold!= null) bold = cn.bold?"bold":"";
  	  
  	  ce.context2D.font = "$italic $bold ${viltage.fontSize}px ${cn.fontName==null?viltage.fontName:cn.fontName}";
  	  
  	  ce.context2D.fillText(cn.char, viltage.offX/4-viltage.fontSize/10, viltage.offY/3*2 + viltage.fontSize/10);
	  }
	  var dataUrl = ce.toDataUrl("image/png");
	  var ie = new ImageElement();
	  ie.src = dataUrl;
	  CanvasPattern p = ce.context2D.createPattern(ie, "no-repeat");
	  cachedNodes[cn.copy()] = p;
	  return p;
	}
	
	/* stores CharNode and CanvasElement pairs */
	static HashMap<CharNode, CanvasPattern> cachedNodes = new HashMap<CharNode, CanvasPattern>();
	
	static update(List<List<Entity>> entities, double delta) {
		for(int i = 0; i < entities.length; i++) {
			for(int j = 0; j < entities[i].length; j++) {
				if(entities[i][j].active) {
				  entities[i][j].update(delta);
				  entities[i][j].updateAnimations(delta);
			  }
			}
		}
	}
}

==> 0.3.3%2B24.tar.gz: lib/etc/utility.dart <==
part of viltage;

class Utility {
	static render(List<List<Entity>> entities, List<List<CharNode>> charArray) {
		for(int i = 0; i < entities.length; i++) {
			for(int j = 0; j < entities[i].length; j++) {
				entities[i][j].render(charArray);
			}
		}
	}
	  
	static draw(CanvasRenderingContext2D ctx, int offX, int offY, VilTAGE viltage) {
	  List<List<CharNode>> charArray = viltage.charArray;
	  for(int i = 0; i < charArray.length; i++) {
			for(int j = 0; j < charArray[0].length; j++) {
			  ctx.drawImage(getImage(charArray[i][j], viltage), j*offX, i*offY);
  		}
	  }
	}
	
	static bool printCaching = false;
	
	static CanvasElement getImage(CharNode cn, VilTAGE viltage) {
	  CanvasElement image;
      
    image = cachedNodes[cn.getString(viltage)];
	  
	  if(image == null) {
	    image = createImage(cn, viltage);
	    if(printCaching) print('Cached "${cn.char}" background color: "${cn.backgroundColor==null?viltage.backgroundColor:cn.backgroundColor}" color: "${cn.color}" font: "${cn.fontName==null?viltage.fontName:cn.fontName}" bold: "${cn.bold==null?viltage.bold:cn.bold}" italic: "${cn.italic==null?viltage.italic:cn.italic}"');
	  }
	  
	  return image;
	}
	
	static CanvasElement createImage(CharNode cn, VilTAGE viltage) {
	  CanvasElement ce = new CanvasElement(width: viltage.offX, height: viltage.offY);
	  
	  if(cn.backgroundColor == null) ce.context2D.fillStyle = viltage.backgroundColor;
	  else ce.context2D.fillStyle = cn.backgroundColor;
	  ce.context2D.fillRect(0, 0, ce.width, ce.height);
	  if(cn.char != null && ce.text != " " && cn.char.length <= 1) {
      ce.context2D.fillStyle = cn.color;
  
      String italic = viltage.italic?"italic":"";
      if(cn.italic != null) italic = cn.italic?"italic":"";
      String bold = viltage.bold?"bold":"";
      if(cn.bold!= null) bold = cn.bold?"bold":"";
  	  ce.context2D.font = "$italic $bold ${viltage.fontSize}px ${cn.fontName==null?viltage.fontName:cn.fontName}";
  	  double width = viltage.ce.context2D.measureText(cn.char).width;
  	  ce.context2D.fillText(cn.char, (viltage.offX-width*1.3)/2, viltage.offY/3*2 + viltage.fontSize/10);
	  }
	  cachedNodes[cn.getString(viltage)] = ce;
	  return ce;
	}
	
	/* stores String and CanvasElement pairs */
	static HashMap<String, CanvasElement> cachedNodes = new HashMap<String, CanvasElement>();
	
	static update(VilTAGEScreen screen, double delta) {
		for(int i = 0; i < screen.entities.length; i++) {
			for(int j = 0; j < screen.entities[i].length; j++) {
				if(screen.entities[i][j].active) {
				  screen.entities[i][j].update(delta);
				  screen.entities[i][j].updateAnimations(delta);
			  }
			}
		}
	}
}
